@@ -8,7 +8,7 @@
 #define STEAM_DIR "/usr/share/steam"
 
 #define PREFIX_DIR "/usr"
-#define INSTALL_DIR "/root/steam-2_1/debian/steam"
+#define INSTALL_DIR "/"
 
 #define JAVA_HOME ""
 
