@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  * 
- * $Id: config.h,v 1.13 2006/05/04 13:46:30 exodusd Exp $
+ * $Id: config.h,v 1.33 2006/10/13 14:58:04 exodusd Exp $
  */
 
 #ifndef _CONFIG_H
@@ -24,10 +24,10 @@
 //#define PROFILING 
 //#define DEBUG_MEMORY
 //#define EVENT_DEBUG
-#define DEBUG_SECURITY
-#define DEBUG_EVENTS 1
-#define DEBUG_HTTP 1
-#define DEBUG_SECURITY
+//#define DEBUG_SECURITY
+//#define DEBUG_EVENTS 1
+//#define DEBUG_HTTP 1
+//#define DEBUG_SECURITY
 
 #define LOG_LEVEL_NONE 0
 #define LOG_LEVEL_ERROR 1
@@ -59,7 +59,7 @@
 #define OBJ_TELNET "/net/telnet.pike"
 #define OBJ_XMLRPC "/net/xmlrpc.pike"
 
-#define STEAM_VERSION "2.2.12"
+#define STEAM_VERSION "2.2.31"
 
 #define CLASS_PATH "classes/"
 
