@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2004  Thomas Bopp, Thorsten Hampel, Ludger Merkens
+/* Copyright (C) 2000-2006  Thomas Bopp, Thorsten Hampel, Ludger Merkens
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  * 
- * $Id: events.h,v 1.1.1.1 2005/09/21 14:22:14 exodusd Exp $
+ * $Id: events.h,v 1.1.1.1 2006/03/27 12:40:10 exodusd Exp $
  */
 
 #ifndef _EVENT_H
@@ -30,6 +30,8 @@
 #define EVENTS_MONITORED         0x20000000
 #define EVENTS_SECOND            0x40000000
 
+#define EVENT_MASK               0xffffffff - EVENTS_MONITORED
+
 
 #define EVENT_ENTER_INVENTORY          1
 #define EVENT_LEAVE_INVENTORY          2
@@ -70,6 +72,9 @@
 #define EVENT_REMOVE_ANNOTATION  (128|EVENTS_SECOND)
 #define EVENT_DOWNLOAD_FINISHED  (256|EVENTS_SECOND)
 #define EVENT_LOCK               (512|EVENTS_SECOND)
+#define EVENT_USER_JOIN_GROUP    (1024|EVENTS_SECOND)
+#define EVENT_USER_LEAVE_GROUP   (2048|EVENTS_SECOND)
+
 #define EVENT_USER_NEW_TICKET    (EVENT_USER_CHANGE_PW|EVENTS_SECOND)
 
 #define EVENTS_OBSERVE (EVENT_SAY|EVENT_ENTER_INVENTORY|EVENT_LEAVE_INVENTORY)
