@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  * 
- * $Id: macros.h,v 1.1.1.1 2005/09/21 14:22:14 exodusd Exp $
+ * $Id: macros.h,v 1.1.1.1 2006/03/27 12:40:10 exodusd Exp $
  */
 
 #ifndef _MACROS_H
@@ -60,7 +60,7 @@
 #define TRACE(s) 
 #endif
 
-#define LOG_DB(s) catch {_Server->get_module("log")->log_database(s); }
+#define LOG_DB(s) catch {_Server->get_module("log")->log_text("database",s); }
 //#define LOG_DB
 
 //#define LOG_DB(s) werror("DB:"+s+"\n")
