@@ -1,6 +1,6 @@
 /*
  * Pike Extension Modules - A collection of modules for the Pike Language
- * Copyright  2000-2005 The Caudium Group
+ * Copyright  2000-2003 The Caudium Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: xml_sax.c,v 1.1.1.1 2006/03/27 12:40:18 exodusd Exp $
+ * $Id: xml_sax.c,v 1.2 2006/06/01 20:35:24 astra Exp $
  */
 
 /*
@@ -63,6 +63,9 @@
 
 //#define SAX_DEBUG 1
 
+#include "global.h"
+RCSID("$Id: xml_sax.c,v 1.2 2006/06/01 20:35:24 astra Exp $");
+
 #ifdef fp
 #undef fp
 #endif
@@ -77,7 +80,8 @@
 #include <stddef.h>
 #include <limits.h>
 
-#include <libxml/SAX2.h>
+#include <libxml/tree.h>
+#include <libxml/SAX.h>
 #include <libxml/entities.h>
 #include <libxml/parserInternals.h>
 
@@ -125,10 +129,7 @@ static unsigned int   __debug_indent;
 #define getParameterEntitySAX 0x16
 #define cdataBlockSAX 0x17
 #define externalSubsetSAX 0x18
-#define startElementNsSAX2 0x19
-#define endElementNsSAX2 0x1A
-#define structuredError 0x1B
-#define CB_API_SIZE 0x1C
+#define CB_API_SIZE 0x19
 
 typedef enum {
   PARSE_PUSH_PARSER = 0x01,
@@ -161,7 +162,8 @@ static int pextsIsStandalone(void *ctx);
 static int pextsHasInternalSubset(void *ctx);
 static int pextsHasExternalSubset(void *ctx);
 static xmlEntityPtr pextsGetEntity(void *ctx, const xmlChar *name);
-static void pextsEntityDecl(void *ctx, const xmlChar *name, int type, const xmlChar *publicId, const xmlChar *systemId, xmlChar *content);
+static void pextsEntityDecl(void *ctx, const xmlChar *name, int type, const xmlChar *publicId,
+                            const xmlChar *systemId, xmlChar *content);
 static void pextsNotationDecl(void *ctx, const xmlChar *name, const xmlChar *publicId, const xmlChar *systemId);
 static void pextsAttributeDecl(void *ctx, const xmlChar *elem, const xmlChar *fullname, int type, int def,
                                const xmlChar *defaultValue, xmlEnumerationPtr tree);
@@ -184,21 +186,7 @@ static void pextsFatalError(void *ctx, const char *msg, ...);
 static xmlEntityPtr pextsGetParameterEntity(void *ctx, const xmlChar *name);
 static void pextsCdataBlock(void *ctx, const xmlChar *value, int len);
 static void pextsExternalSubset(void *ctx, const xmlChar *name, const xmlChar *externalID, const xmlChar *systemID);
-static void pextsStartElementNs(void * ctx, 
-                                const xmlChar * localname, 
-                                const xmlChar * prefix, 
-                                const xmlChar * URI, 
-                                int nb_namespaces, 
-                                const xmlChar ** namespaces, 
-                                int nb_attributes, 
-                                int nb_defaulted, 
-                                const xmlChar ** attributes);
-static void pextsEndElementNs(void * ctx, 
-                              const xmlChar * localname, 
-                              const xmlChar * prefix, 
-                              const xmlChar * URI);
-static void pextsStructuredError(void * userData, xmlErrorPtr error);
-
+  
 static struct program  *xml_program;
 static struct program  *html_program;
 
@@ -229,12 +217,9 @@ static pikeCallbackAPI  callback_api[] =
   CB_OPT_API(getParameterEntitySAX, getParameterEntity),
   CB_OPT_API(cdataBlockSAX, cdataBlock),
   CB_OPT_API(externalSubsetSAX, externalSubset),
-  CB_OPT_API(startElementNsSAX2, startElementNs),
-  CB_OPT_API(endElementNsSAX2, endElementNs),
-  CB_OPT_API(structuredError, serror),
 };
 
-static struct _xmlSAXHandler   pextsSAX = {
+static xmlSAXHandler   pextsSAX = {
   .internalSubset = pextsInternalSubset,
   .isStandalone = pextsIsStandalone,
   .hasInternalSubset = pextsHasInternalSubset,
@@ -261,10 +246,7 @@ static struct _xmlSAXHandler   pextsSAX = {
   .fatalError = pextsFatalError,
   .getParameterEntity = pextsGetParameterEntity,
   .cdataBlock = pextsCdataBlock,
-  .externalSubset = pextsExternalSubset,
-  .startElementNs = pextsStartElementNs,
-  .endElementNs = pextsEndElementNs,
-  .serror = pextsStructuredError,
+  .externalSubset = pextsExternalSubset
 };
 
 static struct pike_string  *econtent_type;
@@ -273,17 +255,6 @@ static struct pike_string  *econtent_name;
 static struct pike_string  *econtent_prefix;
 static struct pike_string  *econtent_c1;
 static struct pike_string  *econtent_c2;
-static struct pike_string  *seDomain;
-static struct pike_string  *seCode;
-static struct pike_string  *seMessage;
-static struct pike_string  *seLevel;
-static struct pike_string  *seFile;
-static struct pike_string  *seLine;
-static struct pike_string  *seStr1;
-static struct pike_string  *seStr2;
-static struct pike_string  *seStr3;
-static struct pike_string  *seInt1;
-static struct pike_string  *seInt2;
 
 /* Parser callbacks */
 
@@ -380,8 +351,8 @@ static xmlEntityPtr pextsGetEntity(void *ctx, const xmlChar *name)
     DBG_FUNC_LEAVE();
     return NULL;
   }
-
   DBG_FUNC_LEAVE();
+  return xmlGetPredefinedEntity(name);
   return NULL;
 }
 
@@ -906,142 +877,6 @@ static void pextsExternalSubset(void *ctx, const xmlChar *name, const xmlChar *e
   DBG_FUNC_LEAVE();
 }
 
-static void pextsStartElementNs(void * ctx, 
-                                const xmlChar * localname, 
-                                const xmlChar * prefix, 
-                                const xmlChar * URI, 
-                                int nb_namespaces, 
-                                const xmlChar ** namespaces, 
-                                int nb_attributes, 
-                                int nb_defaulted, 
-                                const xmlChar ** attributes)
-{
-  int i;
-  
-  DBG_FUNC_ENTER();
-  if (CB_ABSENT(startElementNsSAX2)) {
-    DBG_FUNC_LEAVE();
-    return;
-  }
-
-  THIS->ctxt = (xmlParserCtxtPtr)ctx;
-  
-  push_object(this_object());
-  safe_push_text(localname);
-  safe_push_text(prefix);
-  safe_push_text(URI);
-
-  if (nb_namespaces) {
-    struct array     *arr;
-    
-    for (i = 0; i < nb_namespaces; i++)
-      safe_push_text(namespaces[i]);
-    arr = aggregate_array(nb_namespaces);
-    push_array(arr);
-  } else
-    push_int(0);
-
-  if (nb_attributes) {
-    struct array     *arr;
-    
-    push_int(nb_defaulted);
-    for (i = 0; i < nb_attributes; i++)
-     safe_push_text(attributes[i]);
-    arr = aggregate_array(nb_attributes);
-    push_array(arr);
-  } else {
-    push_int(0);
-    push_int(0);
-  }
-  push_svalue(&THIS->user_data);
-  CB_CALL(startElementNsSAX2, 7);
-  pop_stack();
-
-  DBG_FUNC_LEAVE();
-}
-
-static void pextsEndElementNs(void * ctx, 
-                              const xmlChar * localname, 
-                              const xmlChar * prefix, 
-                              const xmlChar * URI)
-{
-  DBG_FUNC_ENTER();
-  if (CB_ABSENT(endElementNsSAX2)) {
-    DBG_FUNC_LEAVE();
-    return;
-  }
-
-  THIS->ctxt = (xmlParserCtxtPtr)ctx;
-  
-  push_object(this_object());
-  safe_push_text(localname);
-  safe_push_text(prefix);
-  safe_push_text(URI);
-  push_svalue(&THIS->user_data);
-  CB_CALL(endElementNsSAX2, 7);
-  pop_stack();
-
-  DBG_FUNC_LEAVE();
-}
-
-static void pextsStructuredError(void * userData, xmlErrorPtr error)
-{
-  int mcount = 6;
-  
-  DBG_FUNC_ENTER();
-  if (CB_ABSENT(structuredError)) {
-    DBG_FUNC_LEAVE();
-    return;
-  }
-
-  push_object(this_object());
-
-  push_string(seDomain);
-  push_int(error->domain);
-  push_string(seCode);
-  push_int(error->code);
-  if (error->message) {
-    push_string(seMessage);
-    safe_push_text(error->message);
-    mcount++;
-  }
-  push_string(seLevel);
-  push_int(error->level);
-  if (error->file) {
-    push_string(seFile);
-    safe_push_text(error->file);
-    mcount++;
-  }
-  push_string(seLine);
-  push_int(error->line);
-  if (error->str1) {  
-    push_string(seStr1);
-    safe_push_text(error->str1);
-    mcount++;
-  }
-  if (error->str2) {  
-    push_string(seStr2);
-    safe_push_text(error->str2);
-    mcount++;
-  }
-  if (error->str3) {  
-    push_string(seStr3);
-    safe_push_text(error->str3);
-    mcount++;
-  }
-  push_string(seInt1);
-  push_int(error->int1);
-  push_string(seInt2);
-  push_int(error->int2);
-  f_aggregate_mapping(mcount << 1);
-  
-  push_svalue(&THIS->user_data);
-  CB_CALL(structuredError, 3);
-  pop_stack();
-
-  DBG_FUNC_LEAVE();
-}
-
 /* To learn which callbacks are required take a look at the callbacks_api
  * array above.
  */
@@ -1065,9 +900,6 @@ static int is_callback_ok(struct object *callbacks, char **missing_method)
    * storage so that the methods can be called later on.
    */
   while (i < CB_API_SIZE) {
-      if ( callback_api[i].name == NULL ) 
-	  fprintf(stderr, "No name set for API %d\n", i);
-
     ioff = find_identifier(callback_api[i].name, callbacks->prog);
     if (ioff < 0 && callback_api[i].req) {
       if (missing_method)
@@ -1108,7 +940,7 @@ static void f_getLineNumber(INT32 args)
   if (!THIS->ctxt)
     push_int(-1);
   else
-    push_int(xmlSAX2GetLineNumber(THIS->ctxt));
+    push_int(getLineNumber(THIS->ctxt));
 }
 
 /*! @decl int getColumnNumber()
@@ -1120,7 +952,7 @@ static void f_getColumnNumber(INT32 args)
   if (!THIS->ctxt)
     push_int(-1);
   else
-    push_int(xmlSAX2GetColumnNumber(THIS->ctxt));
+    push_int(getColumnNumber(THIS->ctxt));
 }
 
 /*! @decl void create(string|object input, object callbacks, mapping|void  entities, mixed|void user_data, int|void input_is_data)
@@ -1251,18 +1083,32 @@ static void f_parse_xml(INT32 args)
 static void f_parse_html(INT32 args)
 {
   xmlDocPtr   doc = NULL;
+  char * encoding = "utf-8";
+  struct pike_string *encode_data = NULL;
   
+  if ( args == 1 ) {
+      if ( ARG(1).type != T_STRING ) 
+	  Pike_error("Incorrect type for argument 0: expected string (encoding)\n");
+      encode_data = ARG(1).u.string;
+      encoding = encode_data->str;
+  }
+  // do nothing
+  if ( THIS->input_data->len == 0 )
+    push_int(0);
+
   switch (THIS->parsing_method) {
       case PARSE_PUSH_PARSER:
         Pike_error("Push parser not implemented yet. Please bug grendel@caudium.net to implement it.");
         
       case PARSE_MEMORY_PARSER:
-        doc = htmlSAXParseDoc(THIS->input_data->str, NULL, THIS->sax, NULL);
+        htmlHandleOmittedElem(1);
+	doc=htmlSAXParseDoc(THIS->input_data->str, encoding, THIS->sax, NULL);
         break;
 
       case PARSE_FILE_PARSER:
-        doc = htmlSAXParseFile(THIS->input_data->str, NULL, THIS->sax, NULL);
-        break;
+        htmlHandleOmittedElem(1);
+	doc=htmlSAXParseFile(THIS->input_data->str, "utf-8", THIS->sax, NULL);
+	break;
   }
   if ( doc != NULL )
     xmlFreeDoc(doc);
@@ -1289,17 +1135,6 @@ static void init_sax(struct object *o)
   econtent_prefix = make_shared_string("prefix");
   econtent_c1 = make_shared_string("child1");
   econtent_c2 = make_shared_string("child2");
-  seDomain = make_shared_string("domain");
-  seCode = make_shared_string("code");
-  seMessage = make_shared_string("message");
-  seLevel = make_shared_string("level");
-  seFile = make_shared_string("file");
-  seLine = make_shared_string("line");
-  seStr1 = make_shared_string("str1");
-  seStr2 = make_shared_string("str2");
-  seStr3 = make_shared_string("str3");
-  seInt1 = make_shared_string("int1");
-  seInt2 = make_shared_string("int2");
 }
 
 static void exit_sax(struct object *o)
@@ -1316,17 +1151,6 @@ static void exit_sax(struct object *o)
   if (econtent_prefix) free_string(econtent_prefix);
   if (econtent_c1) free_string(econtent_c1);
   if (econtent_c2) free_string(econtent_c2);
-  if (seDomain) free_string(seDomain);
-  if (seCode) free_string(seCode);
-  if (seMessage) free_string(seMessage);
-  if (seLevel) free_string(seLevel);
-  if (seFile) free_string(seFile);
-  if (seLine) free_string(seLine);
-  if (seStr1) free_string(seStr1);
-  if (seStr2) free_string(seStr2);
-  if (seStr3) free_string(seStr3);
-  if (seInt1) free_string(seInt1);
-  if (seInt2) free_string(seInt2);
 }
 
 int _init_xml_sax(void)
@@ -1354,7 +1178,7 @@ int _init_xml_sax(void)
 
   ADD_FUNCTION("create", f_create,
                tFunc(tOr(tString, tObj) tObj tOr(tMapping, tVoid) tOr(tMixed, tVoid) tOr(tInt, tVoid), tVoid), 0);
-  ADD_FUNCTION("parse", f_parse_html, tFunc(tVoid, tInt), 0);
+  ADD_FUNCTION("parse", f_parse_html, tFunc(tOr(tString,tVoid), tInt), 0);
   ADD_FUNCTION("getLineNumber", f_getLineNumber, tFunc(tVoid, tInt), 0);
   ADD_FUNCTION("getColumnNumber", f_getColumnNumber, tFunc(tVoid, tInt), 0);
   
