@@ -31,7 +31,7 @@ struct Global_options
 
 } Global;
 
-#define CALLBACK_API_SIZE 8
+#define CALLBACK_API_SIZE 10
 #define cb_annotation    0x00
 #define cb_linkInternal  0x01
 #define cb_image         0x02
@@ -40,6 +40,8 @@ struct Global_options
 #define cb_embed         0x05
 #define cb_pike          0x06
 #define cb_tag           0x07
+#define cb_heading       0x08
+#define cb_math          0x09
 
 
 typedef struct 
@@ -55,6 +57,24 @@ typedef struct
 
 } wiki_store;
 
+#if defined(PIKE_THREADS) && defined(_REENTRANT)
+#define THREAD_SAFE_RUN(COMMAND)  do {\
+  struct thread_state *state;\
+ if((state = thread_state_for_id(th_self()))!=NULL) {\
+    if(!state->swapped) {\
+      COMMAND;\
+    } else {\
+      mt_lock(&interpreter_lock);\
+      SWAP_IN_THREAD(state);\
+      COMMAND;\
+      SWAP_OUT_THREAD(state);\
+      mt_unlock(&interpreter_lock);\
+    }\
+  }\
+} while(0)
+#else
+#define THREAD_SAFE_RUN(COMMAND) COMMAND
+#endif
 
 
 #endif
