@@ -10,6 +10,7 @@
 
 #include "boolean.h"
 
+void math(char* formula);
 void barelink(char *link);
 void blank_line(void);
 void bold(void);
@@ -22,6 +23,7 @@ void italic(void);
 void make_list(char *list);
 void paragraph(char *text);
 void plaintext(char *text);
+void head(char *text);
 void preformat(void);
 void wikilink(char *link);
 void tag(char *tagstr);
@@ -37,6 +39,8 @@ typedef struct {
     status_t status;
 } lexer_t;
 
+typedef enum { start, end, next } list_t;
+
 void prepare_status(status_t new);
 
 #endif
